@@ -2,7 +2,7 @@
 
 __author__ = """François Durand"""
 __email__ = 'fradurand@gmail.com'
-__version__ = '0.23.0'
+__version__ = '0.24.0'
 
 
 # Utils
@@ -110,7 +110,9 @@ from poisson_approval.random_factories.RandTauVectorUniform import RandTauVector
 from poisson_approval.meta_analysis.NiceStatsProfileOrdinal import NiceStatsProfileOrdinal
 from poisson_approval.meta_analysis.binary_plots import BinaryAxesSubplotPoisson, binary_figure
 from poisson_approval.meta_analysis.binary_shortcuts import binary_plot_n_equilibria, \
-    binary_plot_winners_at_equilibrium, binary_plot_winning_frequencies, XyyToProfile
+    binary_plot_winners_at_equilibrium, binary_plot_winning_frequencies, binary_plot_convergence, \
+    XyyToProfile
 from poisson_approval.meta_analysis.ternary_plots import TernaryAxesSubplotPoisson, ternary_figure
 from poisson_approval.meta_analysis.ternary_shortcuts import ternary_plot_n_equilibria, \
-    ternary_plot_winners_at_equilibrium, ternary_plot_winning_frequencies, SimplexToProfile
+    ternary_plot_winners_at_equilibrium, ternary_plot_winning_frequencies, ternary_plot_convergence, \
+    SimplexToProfile
