@@ -4,15 +4,16 @@ import numpy as np
 from fractions import Fraction
 from poisson_approval.constants.constants import *
 from poisson_approval.constants.EquilibriumStatus import EquilibriumStatus
-from poisson_approval.random_factories.RandStrategyThresholdUniform import RandStrategyThresholdUniform
 from poisson_approval.profiles.Profile import Profile
+from poisson_approval.random_factories.RandStrategyThresholdUniform import RandStrategyThresholdUniform
+from poisson_approval.random_factories.RandTauVectorUniform import RandTauVectorUniform
 from poisson_approval.strategies.Strategy import Strategy
 from poisson_approval.strategies.StrategyThreshold import StrategyThreshold
 from poisson_approval.tau_vector.TauVector import TauVector
 from poisson_approval.utils.ComputationEngineNumeric import ComputationEngineNumeric
 from poisson_approval.utils.DictPrintingInOrderIgnoringZeros import DictPrintingInOrderIgnoringZeros
 from poisson_approval.utils.Util import candidates_to_probabilities, my_division, array_to_d_candidate_value, \
-    one_over_t_plus_one, to_callable, candidates_to_d_candidate_probability
+    one_over_t, to_callable, candidates_to_d_candidate_probability
 from poisson_approval.utils.UtilBallots import ballot_one, ballot_one_two, ballot_low_u, ballot_high_u
 from poisson_approval.utils.UtilCache import cached_property, property_deleting_cache
 
@@ -279,10 +280,16 @@ class ProfileCardinal(Profile):
         Parameters
         ----------
         init : Strategy or TauVector or str
-            If it is a strategy, it must be an argument accepted by :meth:`tau`, i.e. by :meth:`tau_strategic`.
-            If it is a tau-vector, it is used directly. If it is the string ``'sincere'`` or ``'fanatic'``,
-            then :attr:`tau_sincere` or :attr:`tau_fanatic` is respectively used. If it is the string ``'random'``,
-            then :meth:`random_strategy` is used.
+
+            * If it is a strategy, it must be an argument accepted by :meth:`tau`, i.e. by :meth:`tau_strategic`.
+            * If it is a tau-vector, it is used directly.
+            * If it is a string:
+
+              * ``'sincere'`` or ``'fanatic'``: :attr:`tau_sincere` or :attr:`tau_fanatic` is respectively used.
+              * ``'random_tau'``: use :class:`RandTauVectorUniform` to draw a tau-vector uniformly at random that
+                is consistent with the voting rule.
+              * ``'random_tau_undominated'``: use :meth:`random_tau_undominated` to draw a tau-vector where all voters
+                cast an undominated ballot at random.
 
         Returns
         -------
@@ -297,9 +304,6 @@ class ProfileCardinal(Profile):
         if isinstance(init, Strategy):
             strategy = init.deepcopy_with_attached_profile(self)
             tau = strategy.tau
-        elif init == 'random':
-            strategy = self.random_strategy(profile=self)
-            tau = strategy.tau
         else:
             strategy = None
             if isinstance(init, TauVector):
@@ -308,21 +312,34 @@ class ProfileCardinal(Profile):
                 tau = self.tau_sincere
             elif init == 'fanatic':
                 tau = self.tau_fanatic
+            elif init == 'random_tau':
+                tau = RandTauVectorUniform(voting_rule=self.voting_rule)()
+            elif init == 'random_tau_undominated':
+                tau = self.random_tau_undominated()
             else:  # pragma: no cover
                 raise ValueError
         return strategy, tau
 
     def iterated_voting(self, init, n_max_episodes,
                         perception_update_ratio=1, ballot_update_ratio=1,
-                        winning_frequency_update_ratio=one_over_t_plus_one, verbose=False):
+                        winning_frequency_update_ratio=one_over_t, verbose=False):
         """Seek for convergence by iterated voting.
 
         Parameters
         ----------
         init : Strategy or TauVector or str
-            The initialization. If it is a strategy, it must be an argument accepted by :meth:`tau`, i.e. by
-            :meth:`tau_strategic`. If it is a tau-vector, it is used directly. If it is the string ``'sincere'`` or
-            ``'fanatic'``, then :attr:`tau_sincere` or :attr:`tau_fanatic` is respectively used.
+            The initialization.
+
+            * If it is a strategy, it must be an argument accepted by :meth:`tau`, i.e. by :meth:`tau_strategic`.
+            * If it is a tau-vector, it is used directly.
+            * If it is a string:
+
+              * ``'sincere'`` or ``'fanatic'``: :attr:`tau_sincere` or :attr:`tau_fanatic` is respectively used.
+              * ``'random_tau'``: use :class:`RandTauVectorUniform` to draw a tau-vector uniformly at random that
+                is consistent with the voting rule.
+              * ``'random_tau_undominated'``: use :meth:`random_tau_undominated` to draw a tau-vector where all voters
+                cast an undominated ballot at random.
+
         n_max_episodes : int
             Maximal number of iterations.
         perception_update_ratio : Number in [0, 1]
@@ -336,7 +353,7 @@ class ProfileCardinal(Profile):
             ``d_candidate_winning_frequency[c] =
             (1 - winning_frequency_update_ratio(t)) * d_candidate_winning_frequency[c]
             + winning_frequency_update_ratio(t) * winning_probability[c]``.
-            The default function is :func:`~utils.Util.one_over_t_plus_one`, which leads to an arithmetic average.
+            The default function is :func:`~utils.Util.one_over_t`, which leads to an arithmetic average.
             Note that this parameters has an influence only in case of non-convergence.
         verbose : bool
             If True, print all intermediate steps.
@@ -376,41 +393,48 @@ class ProfileCardinal(Profile):
         """
         winning_frequency_update_ratio = to_callable(winning_frequency_update_ratio)
         strategy, tau_actual = self._initializer(init)
-        tau_perceived = tau_actual
-        strategies = [strategy]
-        taus_actual = [tau_actual]
-        taus_perceived = [tau_perceived]
-        array_candidate_winning_frequency = candidates_to_probabilities(tau_actual.winners)
+        tau_perceived = None
         if verbose:
             print('t = %s' % 0)
             print('strategy: %s' % strategy)
             print('tau_actual: %s' % tau_actual)
+        strategies = []
+        taus_actual = []
+        taus_perceived = []
+        array_candidate_winning_frequency = None
         n_episodes = n_max_episodes
         for t in range(1, n_max_episodes + 1):
-            tau_perceived = TauVector({
-                ballot: _my_round(ComputationEngineNumeric.barycenter(a=tau_perceived.d_ballot_share[ballot],
-                                                                      b=tau_actual.d_ballot_share[ballot],
-                                                                      ratio_b=perception_update_ratio))
-                for ballot in BALLOTS_WITHOUT_INVERSIONS
-            }, voting_rule=self.voting_rule, symbolic=self.symbolic)
+            if t == 1:
+                tau_perceived = tau_actual
+            else:
+                tau_perceived = TauVector({
+                    ballot: _my_round(ComputationEngineNumeric.barycenter(a=tau_perceived.d_ballot_share[ballot],
+                                                                          b=tau_actual.d_ballot_share[ballot],
+                                                                          ratio_b=perception_update_ratio))
+                    for ballot in BALLOTS_WITHOUT_INVERSIONS
+                }, voting_rule=self.voting_rule, symbolic=self.symbolic)
             strategy = self.best_responses_to_strategy(tau_perceived.d_ranking_best_response)
             tau_full_response = strategy.tau
-            tau_actual = TauVector({
-                ballot: _my_round(ComputationEngineNumeric.barycenter(a=tau_actual.d_ballot_share[ballot],
-                                                                      b=tau_full_response.d_ballot_share[ballot],
-                                                                      ratio_b=ballot_update_ratio))
-                for ballot in BALLOTS_WITHOUT_INVERSIONS
-            }, normalization_warning=False, voting_rule=self.voting_rule, symbolic=self.symbolic)
-            array_candidate_winning_frequency = (
-                (1 - winning_frequency_update_ratio(t)) * array_candidate_winning_frequency
-                + winning_frequency_update_ratio(t) * candidates_to_probabilities(tau_actual.winners))
+            if t == 1:
+                tau_actual = tau_full_response
+                array_candidate_winning_frequency = candidates_to_probabilities(tau_actual.winners)
+            else:
+                tau_actual = TauVector({
+                    ballot: _my_round(ComputationEngineNumeric.barycenter(a=tau_actual.d_ballot_share[ballot],
+                                                                          b=tau_full_response.d_ballot_share[ballot],
+                                                                          ratio_b=ballot_update_ratio))
+                    for ballot in BALLOTS_WITHOUT_INVERSIONS
+                }, normalization_warning=False, voting_rule=self.voting_rule, symbolic=self.symbolic)
+                array_candidate_winning_frequency = (
+                    (1 - winning_frequency_update_ratio(t)) * array_candidate_winning_frequency
+                    + winning_frequency_update_ratio(t) * candidates_to_probabilities(tau_actual.winners))
             if verbose:
                 print('t = %s' % t)
                 print('tau_perceived: %s' % tau_perceived)
                 print('strategy: %s' % strategy)
                 print('tau_full_response: %s' % tau_full_response)
                 print('tau_actual: %s' % tau_actual)
-            # If there is an symbolic cycle, it is useless to continue looping.
+            # If there is an exact cycle, it is useless to continue looping.
             break_ = (tau_actual, tau_perceived) in zip(taus_actual, taus_perceived)
 
             taus_actual.append(tau_actual)
@@ -441,24 +465,33 @@ class ProfileCardinal(Profile):
                 'd_candidate_winning_frequency': d_candidate_winning_frequency}
 
     def fictitious_play(self, init, n_max_episodes,
-                        perception_update_ratio=one_over_t_plus_one, ballot_update_ratio=1,
-                        winning_frequency_update_ratio=one_over_t_plus_one, verbose=False):
+                        perception_update_ratio=one_over_t, ballot_update_ratio=1,
+                        winning_frequency_update_ratio=one_over_t, verbose=False):
         """Seek for convergence by fictitious play.
 
         Parameters
         ----------
         init : Strategy or TauVector or str
-            The initialization. If it is a strategy, it must be an argument accepted by :meth:`tau`, i.e. by
-            :meth:`tau_strategic`. If it is a tau-vector, it is used directly. If it is the string ``'sincere'`` or
-            ``'fanatic'``, then :attr:`tau_sincere` or :attr:`tau_fanatic` is respectively used.
+            The initialization.
+
+            * If it is a strategy, it must be an argument accepted by :meth:`tau`, i.e. by :meth:`tau_strategic`.
+            * If it is a tau-vector, it is used directly.
+            * If it is a string:
+
+              * ``'sincere'`` or ``'fanatic'``: :attr:`tau_sincere` or :attr:`tau_fanatic` is respectively used.
+              * ``'random_tau'``: use :class:`RandTauVectorUniform` to draw a tau-vector uniformly at random that
+                is consistent with the voting rule.
+              * ``'random_tau_undominated'``: use :meth:`random_tau_undominated` to draw a tau-vector where all voters
+                cast an undominated ballot at random.
+
         n_max_episodes : int
             Maximal number of iterations.
         perception_update_ratio : callable or Number
             The coefficient when updating the perceived tau:
             ``tau_perceived = (1 - perception_update_ratio(t)) * tau_perceived + perception_update_ratio(t) *
             tau_actual``. For any ``t`` from 1 to `n_max_episodes` included, the update ratio must be in [0, 1]. The
-            default function is :func:`~utils.Util.one_over_t_plus_one`, which leads to an arithmetic average. However,
-            the `recommended` function is :func:`~utils.Util.one_over_log_t_plus_two`, which accelerates the
+            default function is :func:`~utils.Util.one_over_t`, which leads to an arithmetic average. However,
+            the `recommended` function is :func:`~utils.Util.one_over_log_t_plus_one`, which accelerates the
             convergence. If `perception_update_ratio` is a Number, it is considered as a constant function.
         ballot_update_ratio : callable or Number
             The ratio of voters who update their ballot:
@@ -471,7 +504,7 @@ class ProfileCardinal(Profile):
             ``d_candidate_winning_frequency[c] =
             (1 - winning_frequency_update_ratio(t)) * d_candidate_winning_frequency[c]
             + winning_frequency_update_ratio(t) * winning_probability[c]``.
-            The default function is :func:`~utils.Util.one_over_t_plus_one`, which leads to an arithmetic average.
+            The default function is :func:`~utils.Util.one_over_t`, which leads to an arithmetic average.
             Note that this parameters has an influence only in case of non-convergence.
         verbose : bool
             If True, print all intermediate steps.
@@ -506,29 +539,35 @@ class ProfileCardinal(Profile):
         winning_frequency_update_ratio = to_callable(winning_frequency_update_ratio)
 
         strategy, tau_actual = self._initializer(init)
-        array_candidate_winning_frequency = candidates_to_probabilities(tau_actual.winners)
-        tau_perceived = tau_actual
+        tau_perceived = None
         if verbose:
             print('t = %s' % 0)
             print('strategy: %s' % strategy)
             print('tau_actual: %s' % tau_actual)
-            print('tau_perceived: %s' % tau_perceived)
+        array_candidate_winning_frequency = None
 
         for t in range(1, n_max_episodes + 1):
-            tau_perceived = TauVector({
-                ballot: _my_round(ComputationEngineNumeric.barycenter(a=tau_perceived.d_ballot_share[ballot],
-                                                                      b=tau_actual.d_ballot_share[ballot],
-                                                                      ratio_b=perception_update_ratio(t)))
-                for ballot in BALLOTS_WITHOUT_INVERSIONS
-            }, voting_rule=self.voting_rule, symbolic=self.symbolic)
+            if t == 1:
+                tau_perceived = tau_actual
+            else:
+                tau_perceived = TauVector({
+                    ballot: _my_round(ComputationEngineNumeric.barycenter(a=tau_perceived.d_ballot_share[ballot],
+                                                                          b=tau_actual.d_ballot_share[ballot],
+                                                                          ratio_b=perception_update_ratio(t)))
+                    for ballot in BALLOTS_WITHOUT_INVERSIONS
+                }, voting_rule=self.voting_rule, symbolic=self.symbolic)
             strategy = self.best_responses_to_strategy(tau_perceived.d_ranking_best_response)
             tau_full_response = strategy.tau
-            tau_actual = TauVector({
-                ballot: _my_round(ComputationEngineNumeric.barycenter(a=tau_actual.d_ballot_share[ballot],
-                                                                      b=tau_full_response.d_ballot_share[ballot],
-                                                                      ratio_b=ballot_update_ratio(t)))
-                for ballot in BALLOTS_WITHOUT_INVERSIONS
-            }, normalization_warning=False, voting_rule=self.voting_rule, symbolic=self.symbolic)
+            if t == 1:
+                tau_actual = tau_full_response
+                array_candidate_winning_frequency = candidates_to_probabilities(tau_actual.winners)
+            else:
+                tau_actual = TauVector({
+                    ballot: _my_round(ComputationEngineNumeric.barycenter(a=tau_actual.d_ballot_share[ballot],
+                                                                          b=tau_full_response.d_ballot_share[ballot],
+                                                                          ratio_b=ballot_update_ratio(t)))
+                    for ballot in BALLOTS_WITHOUT_INVERSIONS
+                }, normalization_warning=False, voting_rule=self.voting_rule, symbolic=self.symbolic)
             array_candidate_winning_frequency = (
                 (1 - winning_frequency_update_ratio(t)) * array_candidate_winning_frequency
                 + winning_frequency_update_ratio(t) * candidates_to_probabilities(tau_actual.winners))
@@ -551,20 +590,6 @@ class ProfileCardinal(Profile):
     def order_and_label(cls, t):
         raise NotImplementedError
 
-    @classmethod
-    def random_strategy(cls, **kwargs):
-        """Random strategy.
-
-        This is a default factory of random strategies. It is used, for example, in
-        :class:`ProfileCardinal.iterated_voting`.
-
-        Returns
-        -------
-        StrategyThreshold
-            Uses :class:`RandStrategyThresholdUniform`.
-        """
-        return RandStrategyThresholdUniform(**kwargs)()
-
 
 def _my_round(x):
     """Round to 0 or 1 if the number is close enough.
